@@ -186,8 +186,11 @@ MYheatmap.2 <- function (x, Rowv = TRUE, Colv = if (symm) "Rowv" else TRUE,
 	}
 	nbr <- length(breaks)
 	ncol <- length(breaks) - 1
-	if (class(col) == "function") 
+	
+	if (is(col, "function")){
 		col <- col(ncol)
+	}
+	
 	min.breaks <- min(breaks)
 	max.breaks <- max(breaks)
 	x[x < min.breaks] <- min.breaks
